@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.0.1';
+our $VERSION = '1.0.2';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -74,12 +74,18 @@ has sync_key => sub{+{}};
 has pass_ticket => '';
 has skey => '';
 has wxsid => '';
-has wxuin => '';;
-has deviceid => sub{my $n = "e";for(my $m = 0;15 > $m;$m++){$n .= POSIX::floor(10 * rand());} $n;};
+has wxuin => '';
+has deviceid => sub{$_[0]->gen_deviceid()};
+has domain => 'wx.qq.com';
 
 has _sync_running => 0;
 has _synccheck_running => 0;
 has _synccheck_error_count => 0;
+sub gen_deviceid {
+    my $self=shift;
+    my $n = "e";for(my $m = 0;15 > $m;$m++){$n .= POSIX::floor(10 * rand());} 
+    $n;
+}
 sub on {
     my $self = shift;
     while(@_){
